@@ -460,7 +460,7 @@ of the syslog(3) system call */
 void LogMsg(int LogLevel, const char * const Msg)
   {
     if (LogLevel <= MaxLogLevel)
-      syslog(LogLevel,Msg);
+      syslog(LogLevel,"%s",Msg);
   }
 
 /* Try to lock the file given in LockFile as pid LockPid using the classical
@@ -1390,7 +1390,8 @@ void HandleCPCCommand(BufferType *SockB, int PortFd, unsigned char * Command, si
             {
               /* Received client signature */
               strncpy(SigStr,(char *) &Command[4],CSize - 6);
-              sprintf(LogStr,"Received client signature: %s",SigStr);
+              snprintf(LogStr,sizeof(LogStr)-1,"Received client signature: %s",SigStr);
+	      LogStr[sizeof(LogStr)-1] = 0;
               LogMsg(LOG_INFO,LogStr);
             }
         break;
